module.exports = defineTest({
	description: 'supports class static initialization blocks'
});
